@@ -262,6 +262,10 @@ enum {
 
 #define DEFAULT_TE_RX_SLEVEL 120
 
+/* Serial RTS/DTS control, default is alwasy HIGH */
+#define WANOPT_HIGH 	0
+#define WANOPT_LOW  	1
+
 typedef char devname_t[WAN_DRVNAME_SZ+1];
 
 
@@ -355,6 +359,8 @@ typedef struct wan_xilinx_conf
 	unsigned int	rbs;		/* Robbit signalling support */
 	unsigned int	data_mux_map;	/* Data mux map */
 	unsigned int	rx_crc_bytes;
+	unsigned char	serial_dtr_ctrl;
+	unsigned char	serial_rts_ctrl;
 #if defined(__WINDOWS__)
 	unsigned short num_of_ch;	/* Number of logical channels */
 	unsigned int   tdmv_span_no;
@@ -657,6 +663,7 @@ typedef struct wan_tdmv_conf_ {
 	unsigned int   span_no;
 	unsigned int   dchan;		/* hwHDLC: PRI SIG */
 	unsigned char  hw_dtmf;		/* TDMV Enable/Disable HW DTMF */
+	unsigned char  hw_fax_detect;   /* TDMV Enable/Disable HW FAX Detect, depends on DTMF */	
 	unsigned char  sdla_tdmv_dummy_enable;
 } wan_tdmv_conf_t;
 
